@@ -66,7 +66,7 @@ class CalculateTest(BaseTest):
     def test_benfords_law(self):
         self.assertEqual(
             calculate.benfords_law([1, 2, 3, 4, 5, 6, 7, 8, 9, 10], verbose=False),
-            -0.8638019376987044
+            -0.863801937698704
         )
         self.assertEqual(
             calculate.benfords_law([1, 2, 3, 4, 5, 6, 7, 8, 9, 10], method="last_digit", verbose=False),
@@ -175,6 +175,16 @@ class CalculateTest(BaseTest):
         with self.assertRaises(ValueError):
             calculate.elfi(['a', 0.2, 3])
     
+    def test_margin_of_victory(self):
+        self.assertEqual(
+            calculate.margin_of_victory([3285, 2804, 7170]),
+            3885
+        )
+        self.assertEqual(
+            calculate.margin_of_victory([50708, 20639]),
+            50708 - 20639
+        )
+    
     def test_mean(self):
         self.assertEqual(calculate.mean([1,2,3]), 2.0)
         self.assertEqual(calculate.mean([1, 99]), 50.0)
